.. _ACE: https://github.com/neurosynth/ACE

.. _AFNI: https://afni.nimh.nih.gov

.. _Anaconda: https://www.anaconda.com/download/#macos

.. _Analysis of Brain Coordinates: https://www.biorxiv.org/content/10.1101/2020.12.03.409953v1

.. _BrainMap: http://www.brainmap.org

.. _BrainSpell: http://brainspell.org/

.. _Cognitive Atlas: http://www.cognitiveatlas.org/

.. _Cognitive Paradigm Ontology: http://www.cogpo.org/

.. _command line interface: cli.html

.. _ERPscanr: https://erpscanr.github.io/ERPscanr/

.. _flake8: https://flake8.pycqa.org/en/latest/

.. _FSL: https://fsl.fmrib.ox.ac.uk

.. _GingerALE: https://www.brainmap.org/ale/

.. _Gradec Documentation: about.html

.. _IBMA SPM extension: https://github.com/NeuroimagingMetaAnalysis/ibma

.. _metaCurious: https://github.com/neurostuff/metaCurious

.. _MKDA Toolbox: https://github.com/canlab/Canlab_MKDA_MetaAnalysis

.. _NeuRoi Toolbox: https://www.nottingham.ac.uk/research/groups/clinicalneurology/neuroi.aspx

.. _NeuroPower: http://neuropowertools.org

.. _NeuroQuery: https://neuroquery.org

.. _NeuroQuery database: https://github.com/neuroquery/neuroquery_data

.. _NeuroScout: https://alpha.neuroscout.org

.. _NeuroStars: https://neurostars.org/latest

.. _NeuroStore: https://github.com/neurostuff/neurostore

.. _NeuroSynth 1.0: http://neurosynth.org/

.. _NeuroSynth 2.0: https://github.com/neurostuff/neurosynth-frontend

.. _Neurosynth Python package: https://github.com/neurosynth/neurosynth

.. _NeuroVault: https://neurovault.org/

.. _Nibabel: https://nipy.org/nibabel/

.. _NIDM Results: http://nidm.nidash.org/specs/nidm-results_130.html

.. _Nilearn: https://nilearn.github.io/

.. _NIMADS: https://github.com/neurostuff/NIMADS

.. _NiMARE Documentation: about.html

.. _NiMARE: https://github.com/neurostuff/NiMARE

.. _Nipype: https://nipype.readthedocs.io/en/latest/index.html

.. _OpenNeuro: https://openneuro.org

.. _PyMARE: https://pymare.readthedocs.io/en/latest/

.. _Python Supported Versions: https://devguide.python.org/versions/#supported-versions

.. _scikit-learn: https://scikit-learn.org/stable/developers/index.html

.. _Scribe: https://brainmap.org/scribe/

.. _SDM: https://www.sdmproject.com

.. _Sleuth: http://www.brainmap.org/software.html#Sleuth

.. _SPM: https://www.fil.ion.ucl.ac.uk/spm/
